==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/app/Settings.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/app/Settings.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../components/toggle-switch/ToggleSwitch.es', './EditAppContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _ToggleSwitch = _interopRequireDefault(require("../../components/toggle-switch/ToggleSwitch.es"));

  var _EditAppContext = _interopRequireWildcard(require("./EditAppContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = function _default(_ref) {
    var deploymentType = _ref.deploymentType,
        _ref$settings = _ref.settings,
        settings = _ref$settings === void 0 ? function () {
      return _react["default"].createElement(_react["default"].Fragment, null);
    } : _ref$settings,
        subtitle = _ref.subtitle,
        title = _ref.title;

    var _useContext = (0, _react.useContext)(_EditAppContext["default"]),
        dispatch = _useContext.dispatch,
        appDeployments = _useContext.state.app.appDeployments;

    var checked = appDeployments.some(function (appDeployment) {
      return appDeployment.type === deploymentType;
    });
    return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement("div", {
      className: "autofit-row mb-3 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement("section", {
      className: "autofit-section"
    }, _react["default"].createElement("h3", null, title), _react["default"].createElement("p", {
      className: "list-group-subtext"
    }, _react["default"].createElement("small", null, subtitle)))), _react["default"].createElement("div", {
      className: "autofit-col right"
    }, _react["default"].createElement(_ToggleSwitch["default"], {
      checked: checked,
      onChange: function onChange(checked) {
        if (checked) {
          dispatch({
            deploymentType: deploymentType,
            type: _EditAppContext.ADD_DEPLOYMENT
          });
        } else {
          dispatch({
            deploymentType: deploymentType,
            type: _EditAppContext.REMOVE_DEPLOYMENT
          });
        }
      }
    }))), checked && settings());
  };

  exports["default"] = _default;
  //# sourceMappingURL=Settings.es.js.map
});
//# sourceMappingURL=Settings.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/app/Settings.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/app/Settings.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../components/toggle-switch/ToggleSwitch.es', './EditAppContext.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _ToggleSwitch = _interopRequireDefault(require("../../components/toggle-switch/ToggleSwitch.es"));

  var _EditAppContext = _interopRequireWildcard(require("./EditAppContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = function _default(_ref) {
    var deploymentType = _ref.deploymentType,
        _ref$settings = _ref.settings,
        settings = _ref$settings === void 0 ? function () {
      return _react["default"].createElement(_react["default"].Fragment, null);
    } : _ref$settings,
        subtitle = _ref.subtitle,
        title = _ref.title;

    var _useContext = (0, _react.useContext)(_EditAppContext["default"]),
        dispatch = _useContext.dispatch,
        appDeployments = _useContext.state.app.appDeployments;

    var checked = appDeployments.some(function (appDeployment) {
      return appDeployment.type === deploymentType;
    });
    return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement("div", {
      className: "autofit-row mb-3 pl-4 pr-4"
    }, _react["default"].createElement("div", {
      className: "autofit-col-expand"
    }, _react["default"].createElement("section", {
      className: "autofit-section"
    }, _react["default"].createElement("h3", null, title), _react["default"].createElement("p", {
      className: "list-group-subtext"
    }, _react["default"].createElement("small", null, subtitle)))), _react["default"].createElement("div", {
      className: "autofit-col right"
    }, _react["default"].createElement(_ToggleSwitch["default"], {
      checked: checked,
      onChange: function onChange(checked) {
        if (checked) {
          dispatch({
            deploymentType: deploymentType,
            type: _EditAppContext.ADD_DEPLOYMENT
          });
        } else {
          dispatch({
            deploymentType: deploymentType,
            type: _EditAppContext.REMOVE_DEPLOYMENT
          });
        }
      }
    }))), checked && settings());
  };

  exports["default"] = _default;
  //# sourceMappingURL=Settings.es.js.map
});
//# sourceMappingURL=Settings.es.js.map
